import {
  getDividerStyles,
  getStackStyles,
  selector
} from "./chunk-VV2VTA7P.mjs";
import {
  __name
} from "./chunk-INDHDMU3.mjs";

// src/stack.tsx
import { isVNode as _isVNode, createVNode as _createVNode, mergeProps as _mergeProps } from "vue";
import { defineComponent, computed, Fragment, createVNode } from "vue";
import { chakra } from "@chakra-ui/vue-system";
function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !_isVNode(s);
}
__name(_isSlot, "_isSlot");
var CStackDivider = defineComponent({
  name: "CStackDivider",
  inheritAttrs: false,
  setup(_, {
    attrs,
    slots
  }) {
    return () => {
      return _createVNode(chakra.div, _mergeProps({
        "__label": "stack__divider",
        "borderWidth": 0,
        "alignSelf": "stretch",
        "borderColor": "inherit",
        "width": "auto",
        "height": "auto"
      }, attrs), {
        default: () => {
          var _a;
          return [(_a = slots == null ? void 0 : slots.default) == null ? void 0 : _a.call(slots)];
        }
      });
    };
  }
});
var CStackItem = defineComponent({
  name: "CStackItem",
  setup(_, {
    attrs,
    slots
  }) {
    return () => _createVNode(chakra.div, _mergeProps({
      "__label": "stack__item",
      "display": "inline-block",
      "flex": "0 0 auto",
      "minWidth": "0"
    }, attrs), {
      default: () => {
        var _a;
        return [(_a = slots == null ? void 0 : slots.default) == null ? void 0 : _a.call(slots)];
      }
    });
  }
});
var stackProps = {
  as: {
    type: [Object, String],
    default: "div"
  },
  align: [String, Array, Object],
  justify: [String, Array, Object],
  wrap: [String, Array, Object],
  spacing: {
    type: [String, Array, Object, Number],
    default: "0.5rem"
  },
  direction: [String, Array, Object],
  // todo: divider
  divider: [Object, Boolean],
  shouldWrapChildren: [Boolean],
  isInline: [Boolean]
};
var CStack = defineComponent({
  name: "CStack",
  props: stackProps,
  setup(props, {
    slots,
    attrs
  }) {
    const direction = computed(() => {
      var _a;
      return props.isInline ? "row" : (_a = props.direction) != null ? _a : "column";
    });
    const styles = computed(() => getStackStyles({
      direction: direction.value,
      spacing: props.spacing
    }));
    const dividerStyle = computed(() => getDividerStyles({
      spacing: props.spacing,
      direction: direction.value
    }));
    const hasDivider = computed(() => !!props.divider);
    const shouldUseChildren = computed(() => !props.shouldWrapChildren && !hasDivider.value);
    return () => {
      var _a;
      const validChildren = (_a = slots.default) == null ? void 0 : _a.call(slots);
      const clones = shouldUseChildren.value ? validChildren : validChildren.map((child, index) => {
        const isLast = index + 1 === validChildren.length;
        const wrappedChild = createVNode(CStackItem, {
          key: index
        }, child);
        const _child = props.shouldWrapChildren ? wrappedChild : child;
        if (!hasDivider.value)
          return _child;
        const clonedDivider = createVNode(CStackDivider, {
          borderColor: "blue.200",
          __css: dividerStyle.value
        });
        const _divider = isLast ? null : clonedDivider;
        return createVNode(Fragment, {
          key: index
        }, [_child, _divider]);
      });
      return _createVNode(chakra.div, _mergeProps({
        "__label": "stack",
        "display": "flex",
        "alignItems": props.align,
        "justifyContent": props.justify,
        "flexDirection": styles.value.flexDirection,
        "flexWrap": props.wrap,
        "__css": hasDivider.value ? {} : {
          [selector]: styles.value[selector]
        }
      }, attrs), _isSlot(clones) ? clones : {
        default: () => [clones]
      });
    };
  }
});
var CHStack = defineComponent({
  name: "CHStack",
  props: stackProps,
  setup(props, {
    attrs,
    slots
  }) {
    return () => _createVNode(CStack, _mergeProps({
      "__label": "stack-horizontal"
    }, props, attrs, {
      "direction": "row"
    }), {
      default: () => {
        var _a;
        return [(_a = slots == null ? void 0 : slots.default) == null ? void 0 : _a.call(slots)];
      }
    });
  }
});
var CVStack = defineComponent({
  name: "CVStack",
  props: stackProps,
  setup(props, {
    attrs,
    slots
  }) {
    return () => _createVNode(CStack, _mergeProps({
      "__label": "stack-vertical"
    }, props, attrs, {
      "direction": "column"
    }), {
      default: () => {
        var _a;
        return [(_a = slots == null ? void 0 : slots.default) == null ? void 0 : _a.call(slots)];
      }
    });
  }
});

export {
  CStackDivider,
  CStackItem,
  CStack,
  CHStack,
  CVStack
};
