import {
  __name
} from "./chunk-INDHDMU3.mjs";

// src/list.tsx
import { createVNode as _createVNode, isVNode as _isVNode, mergeProps as _mergeProps } from "vue";
import { CIcon } from "@chakra-ui/c-icon";
import { useMultiStyleConfig, useStyles, StylesProvider } from "@chakra-ui/vue-system";
import { defineComponent, computed } from "vue";
import { chakra } from "@chakra-ui/vue-system";
import { getValidChildren, SNAO, SAO } from "@chakra-ui/vue-utils";
function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !_isVNode(s);
}
__name(_isSlot, "_isSlot");
var CList = defineComponent({
  name: "CList",
  props: {
    as: {
      type: [Object, String],
      default: "ul"
    },
    styleType: {
      type: SAO,
      default: "none"
    },
    stylePosition: SAO,
    spacing: SNAO
  },
  setup(props, {
    slots,
    attrs
  }) {
    const styles = useMultiStyleConfig("List", props);
    StylesProvider(styles);
    const selector = "& > *:not(style) ~ *:not(style)";
    const spacingStyle = computed(() => props.spacing ? {
      [selector]: {
        mt: props.spacing
      }
    } : {});
    return () => {
      const validChildren = /* @__PURE__ */ __name(() => getValidChildren(slots), "validChildren");
      return _createVNode(chakra.ul, _mergeProps({
        "__label": "list",
        "as": props.as,
        "listStyleType": props.styleType,
        "listStylePosition": props.stylePosition,
        "role": "list",
        "__css": {
          ...styles.value.container,
          ...spacingStyle.value
        }
      }, attrs), _isSlot(validChildren) ? validChildren : {
        default: () => [validChildren]
      });
    };
  }
});
var COrderedList = defineComponent({
  name: "COrderedList",
  setup(props, {
    slots,
    attrs
  }) {
    return () => _createVNode(CList, _mergeProps({
      "styleType": "decimal",
      "marginStart": "1em"
    }, attrs), _isSlot(slots) ? slots : {
      default: () => [slots]
    });
  }
});
var CUnorderedList = defineComponent({
  name: "CUnorderedList",
  setup(props, {
    slots,
    attrs
  }) {
    return () => (
      // @ts-ignore
      _createVNode(CList, _mergeProps({
        "styleType": "initial",
        "marginStart": "1em"
      }, attrs), _isSlot(slots) ? slots : {
        default: () => [slots]
      })
    );
  }
});
var CListItem = defineComponent({
  name: "CListItem",
  setup(_, {
    slots,
    attrs
  }) {
    const styles = useStyles();
    return () => {
      return _createVNode(chakra.li, _mergeProps({
        "__label": "list__item",
        "__css": styles.value.item
      }, attrs), _isSlot(slots) ? slots : {
        default: () => [slots]
      });
    };
  }
});
var CListIcon = defineComponent({
  name: "CListIcon",
  setup(_, {
    slots,
    attrs
  }) {
    const styles = useStyles();
    return () => {
      return _createVNode(CIcon, _mergeProps({
        "role": "presentation"
      }, attrs, {
        "__css": styles.value.icon
      }), _isSlot(slots) ? slots : {
        default: () => [slots]
      });
    };
  }
});

export {
  CList,
  COrderedList,
  CUnorderedList,
  CListItem,
  CListIcon
};
