import * as vue from 'vue';
import { PropType } from 'vue';
import { BoxProps } from './box.js';
import { SystemProps, ResponsiveValue } from '@chakra-ui/styled-system';
import * as CSS from 'csstype';
import '@chakra-ui/vue-system';

interface GridOptions {
    /**
     * Short hand prop for `gridTemplateColumns`
     * @type SystemProps["gridTemplateColumns"]
     */
    templateColumns?: SystemProps["gridTemplateColumns"];
    /**
     * Short hand prop for `gridGap`
     * @type SystemProps["gridGap"]
     */
    gap?: SystemProps["gridGap"];
    /**
     * Short hand prop for `gridRowGap`
     * @type SystemProps["gridRowGap"]
     */
    rowGap?: SystemProps["gridRowGap"];
    /**
     * Short hand prop for `gridColumnGap`
     * @type SystemProps["gridColumnGap"]
     */
    columnGap?: SystemProps["gridColumnGap"];
    /**
     * Short hand prop for `gridAutoFlow`
     * @type SystemProps["gridAutoFlow"]
     */
    autoFlow?: SystemProps["gridAutoFlow"];
    /**
     * Short hand prop for `gridAutoRows`
     * @type SystemProps["gridAutoRows"]
     */
    autoRows?: SystemProps["gridAutoRows"];
    /**
     * Short hand prop for `gridAutoColumns`
     * @type SystemProps["gridAutoColumns"]
     */
    autoColumns?: SystemProps["gridAutoColumns"];
    /**
     * Short hand prop for `gridTemplateRows`
     * @type SystemProps["gridTemplateRows"]
     */
    templateRows?: SystemProps["gridTemplateRows"];
    /**
     * Short hand prop for `gridTemplateAreas`
     * @type SystemProps["gridTemplateAreas"]
     */
    templateAreas?: SystemProps["gridTemplateAreas"];
    /**
     * Short hand prop for `gridArea`
     * @type SystemProps["gridArea"]
     */
    area?: SystemProps["gridArea"];
    /**
     * Short hand prop for `gridColumn`
     * @type SystemProps["gridColumn"]
     */
    column?: SystemProps["gridColumn"];
    /**
     * Short hand prop for `gridRow`
     * @type SystemProps["gridRow"]
     */
    row?: SystemProps["gridRow"];
}
interface CGridProps extends GridOptions {
}
interface CGridItemProps extends BoxProps {
    /**
     * The number of columns the grid item should `span`.
     * @type ResponsiveValue<number | "auto">
     */
    colSpan?: ResponsiveValue<number | "auto">;
    /**
     * The column number the grid item should start.
     * @type ResponsiveValue<number | "auto">
     */
    colStart?: ResponsiveValue<number | "auto">;
    /**
     * @type ResponsiveValue<number | "auto">
     */
    colEnd?: ResponsiveValue<number | "auto">;
    /**
     * @type ResponsiveValue<number | "auto">
     */
    rowStart?: ResponsiveValue<number | "auto">;
    /**
     * @type ResponsiveValue<number | "auto">
     */
    rowEnd?: ResponsiveValue<number | "auto">;
    /**
     * @type ResponsiveValue<number | "auto">
     */
    rowSpan?: ResponsiveValue<number | "auto">;
}
/**
 * Vue component used to create grid layouts.
 *
 * It renders a `div` with `display: grid` and
 * comes with helpful style shorthand.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/grid
 */
declare const CGrid: vue.DefineComponent<{
    as: {
        type: PropType<any>;
        default: string;
    };
    templateColumns: PropType<ResponsiveValue<CSS.Property.GridTemplateColumns<0 | (string & {})>> | undefined>;
    gap: PropType<ResponsiveValue<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "revert-layer" | "unset" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5"> | undefined>;
    rowGap: PropType<ResponsiveValue<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "revert-layer" | "unset" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5"> | undefined>;
    columnGap: PropType<ResponsiveValue<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "revert-layer" | "unset" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5"> | undefined>;
    autoFlow: PropType<ResponsiveValue<CSS.Property.GridAutoFlow> | undefined>;
    autoRows: PropType<ResponsiveValue<CSS.Property.GridAutoRows<0 | (string & {})>> | undefined>;
    autoColumns: PropType<ResponsiveValue<CSS.Property.GridAutoColumns<0 | (string & {})>> | undefined>;
    templateRows: PropType<ResponsiveValue<CSS.Property.GridTemplateRows<0 | (string & {})>> | undefined>;
    templateAreas: PropType<ResponsiveValue<CSS.Property.GridTemplateAreas> | undefined>;
    area: PropType<ResponsiveValue<CSS.Property.GridArea> | undefined>;
    column: PropType<ResponsiveValue<CSS.Property.GridColumn> | undefined>;
    row: PropType<ResponsiveValue<CSS.Property.GridRow> | undefined>;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    as: {
        type: PropType<any>;
        default: string;
    };
    templateColumns: PropType<ResponsiveValue<CSS.Property.GridTemplateColumns<0 | (string & {})>> | undefined>;
    gap: PropType<ResponsiveValue<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "revert-layer" | "unset" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5"> | undefined>;
    rowGap: PropType<ResponsiveValue<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "revert-layer" | "unset" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5"> | undefined>;
    columnGap: PropType<ResponsiveValue<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "revert-layer" | "unset" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5"> | undefined>;
    autoFlow: PropType<ResponsiveValue<CSS.Property.GridAutoFlow> | undefined>;
    autoRows: PropType<ResponsiveValue<CSS.Property.GridAutoRows<0 | (string & {})>> | undefined>;
    autoColumns: PropType<ResponsiveValue<CSS.Property.GridAutoColumns<0 | (string & {})>> | undefined>;
    templateRows: PropType<ResponsiveValue<CSS.Property.GridTemplateRows<0 | (string & {})>> | undefined>;
    templateAreas: PropType<ResponsiveValue<CSS.Property.GridTemplateAreas> | undefined>;
    area: PropType<ResponsiveValue<CSS.Property.GridArea> | undefined>;
    column: PropType<ResponsiveValue<CSS.Property.GridColumn> | undefined>;
    row: PropType<ResponsiveValue<CSS.Property.GridRow> | undefined>;
}>>, {
    as: any;
}>;
declare const CGridItem: vue.DefineComponent<{
    as: {
        type: PropType<any>;
        default: string;
    };
    colSpan: PropType<ResponsiveValue<number | "auto"> | undefined>;
    colStart: PropType<ResponsiveValue<number | "auto"> | undefined>;
    colEnd: PropType<ResponsiveValue<number | "auto"> | undefined>;
    rowStart: PropType<ResponsiveValue<number | "auto"> | undefined>;
    rowEnd: PropType<ResponsiveValue<number | "auto"> | undefined>;
    rowSpan: PropType<ResponsiveValue<number | "auto"> | undefined>;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    as: {
        type: PropType<any>;
        default: string;
    };
    colSpan: PropType<ResponsiveValue<number | "auto"> | undefined>;
    colStart: PropType<ResponsiveValue<number | "auto"> | undefined>;
    colEnd: PropType<ResponsiveValue<number | "auto"> | undefined>;
    rowStart: PropType<ResponsiveValue<number | "auto"> | undefined>;
    rowEnd: PropType<ResponsiveValue<number | "auto"> | undefined>;
    rowSpan: PropType<ResponsiveValue<number | "auto"> | undefined>;
}>>, {
    as: any;
}>;

export { CGrid, CGridItem, CGridItemProps, CGridProps, GridOptions };
