"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/stack.tsx
var stack_exports = {};
__export(stack_exports, {
  CHStack: () => CHStack,
  CStack: () => CStack,
  CStackDivider: () => CStackDivider,
  CStackItem: () => CStackItem,
  CVStack: () => CVStack
});
module.exports = __toCommonJS(stack_exports);
var import_vue = require("vue");
var import_vue2 = require("vue");
var import_vue_system = require("@chakra-ui/vue-system");

// src/stack.utils.ts
var import_utils = require("@chakra-ui/utils");
var selector = "& > *:not(style) ~ *:not(style)";
function getStackStyles(options) {
  const {
    spacing,
    direction
  } = options;
  const directionStyles = {
    column: {
      marginTop: spacing,
      marginEnd: 0,
      marginBottom: 0,
      marginStart: 0
    },
    row: {
      marginTop: 0,
      marginEnd: 0,
      marginBottom: 0,
      marginStart: spacing
    },
    "column-reverse": {
      marginTop: 0,
      marginEnd: 0,
      marginBottom: spacing,
      marginStart: 0
    },
    "row-reverse": {
      marginTop: 0,
      marginEnd: spacing,
      marginBottom: 0,
      marginStart: 0
    }
  };
  return {
    flexDirection: direction,
    [selector]: (0, import_utils.mapResponsive)(direction, (value) => directionStyles[value])
  };
}
__name(getStackStyles, "getStackStyles");
function getDividerStyles(options) {
  const {
    spacing,
    direction
  } = options;
  const dividerStyles = {
    column: {
      my: spacing,
      mx: 0,
      borderLeftWidth: 0,
      borderBottomWidth: "1px"
    },
    "column-reverse": {
      my: spacing,
      mx: 0,
      borderLeftWidth: 0,
      borderBottomWidth: "1px"
    },
    row: {
      mx: spacing,
      my: 0,
      borderLeftWidth: "1px",
      borderBottomWidth: 0
    },
    "row-reverse": {
      mx: spacing,
      my: 0,
      borderLeftWidth: "1px",
      borderBottomWidth: 0
    }
  };
  return {
    "&": (0, import_utils.mapResponsive)(direction, (value) => dividerStyles[value])
  };
}
__name(getDividerStyles, "getDividerStyles");

// src/stack.tsx
function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !(0, import_vue.isVNode)(s);
}
__name(_isSlot, "_isSlot");
var CStackDivider = (0, import_vue2.defineComponent)({
  name: "CStackDivider",
  inheritAttrs: false,
  setup(_, {
    attrs,
    slots
  }) {
    return () => {
      return (0, import_vue.createVNode)(import_vue_system.chakra.div, (0, import_vue.mergeProps)({
        "__label": "stack__divider",
        "borderWidth": 0,
        "alignSelf": "stretch",
        "borderColor": "inherit",
        "width": "auto",
        "height": "auto"
      }, attrs), {
        default: () => {
          var _a;
          return [(_a = slots == null ? void 0 : slots.default) == null ? void 0 : _a.call(slots)];
        }
      });
    };
  }
});
var CStackItem = (0, import_vue2.defineComponent)({
  name: "CStackItem",
  setup(_, {
    attrs,
    slots
  }) {
    return () => (0, import_vue.createVNode)(import_vue_system.chakra.div, (0, import_vue.mergeProps)({
      "__label": "stack__item",
      "display": "inline-block",
      "flex": "0 0 auto",
      "minWidth": "0"
    }, attrs), {
      default: () => {
        var _a;
        return [(_a = slots == null ? void 0 : slots.default) == null ? void 0 : _a.call(slots)];
      }
    });
  }
});
var stackProps = {
  as: {
    type: [Object, String],
    default: "div"
  },
  align: [String, Array, Object],
  justify: [String, Array, Object],
  wrap: [String, Array, Object],
  spacing: {
    type: [String, Array, Object, Number],
    default: "0.5rem"
  },
  direction: [String, Array, Object],
  // todo: divider
  divider: [Object, Boolean],
  shouldWrapChildren: [Boolean],
  isInline: [Boolean]
};
var CStack = (0, import_vue2.defineComponent)({
  name: "CStack",
  props: stackProps,
  setup(props, {
    slots,
    attrs
  }) {
    const direction = (0, import_vue2.computed)(() => {
      var _a;
      return props.isInline ? "row" : (_a = props.direction) != null ? _a : "column";
    });
    const styles = (0, import_vue2.computed)(() => getStackStyles({
      direction: direction.value,
      spacing: props.spacing
    }));
    const dividerStyle = (0, import_vue2.computed)(() => getDividerStyles({
      spacing: props.spacing,
      direction: direction.value
    }));
    const hasDivider = (0, import_vue2.computed)(() => !!props.divider);
    const shouldUseChildren = (0, import_vue2.computed)(() => !props.shouldWrapChildren && !hasDivider.value);
    return () => {
      var _a;
      const validChildren = (_a = slots.default) == null ? void 0 : _a.call(slots);
      const clones = shouldUseChildren.value ? validChildren : validChildren.map((child, index) => {
        const isLast = index + 1 === validChildren.length;
        const wrappedChild = (0, import_vue2.createVNode)(CStackItem, {
          key: index
        }, child);
        const _child = props.shouldWrapChildren ? wrappedChild : child;
        if (!hasDivider.value)
          return _child;
        const clonedDivider = (0, import_vue2.createVNode)(CStackDivider, {
          borderColor: "blue.200",
          __css: dividerStyle.value
        });
        const _divider = isLast ? null : clonedDivider;
        return (0, import_vue2.createVNode)(import_vue2.Fragment, {
          key: index
        }, [_child, _divider]);
      });
      return (0, import_vue.createVNode)(import_vue_system.chakra.div, (0, import_vue.mergeProps)({
        "__label": "stack",
        "display": "flex",
        "alignItems": props.align,
        "justifyContent": props.justify,
        "flexDirection": styles.value.flexDirection,
        "flexWrap": props.wrap,
        "__css": hasDivider.value ? {} : {
          [selector]: styles.value[selector]
        }
      }, attrs), _isSlot(clones) ? clones : {
        default: () => [clones]
      });
    };
  }
});
var CHStack = (0, import_vue2.defineComponent)({
  name: "CHStack",
  props: stackProps,
  setup(props, {
    attrs,
    slots
  }) {
    return () => (0, import_vue.createVNode)(CStack, (0, import_vue.mergeProps)({
      "__label": "stack-horizontal"
    }, props, attrs, {
      "direction": "row"
    }), {
      default: () => {
        var _a;
        return [(_a = slots == null ? void 0 : slots.default) == null ? void 0 : _a.call(slots)];
      }
    });
  }
});
var CVStack = (0, import_vue2.defineComponent)({
  name: "CVStack",
  props: stackProps,
  setup(props, {
    attrs,
    slots
  }) {
    return () => (0, import_vue.createVNode)(CStack, (0, import_vue.mergeProps)({
      "__label": "stack-vertical"
    }, props, attrs, {
      "direction": "column"
    }), {
      default: () => {
        var _a;
        return [(_a = slots == null ? void 0 : slots.default) == null ? void 0 : _a.call(slots)];
      }
    });
  }
});
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  CHStack,
  CStack,
  CStackDivider,
  CStackItem,
  CVStack
});
